==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/response.js <==
joo.classLoader.prepare("package ext.config",/* {

import joo.JavaScriptObject;*/

/**
 * A generic response class to normalize response-handling internally to the framework.
 *
 * <p>This class serves as a
 * typed config object for constructor of class Response.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.data.Response
 */
{ExtConfig:{target:"ext.data.Response"}},
"public class response extends joo.JavaScriptObject",2,function($$private){;return[ 

  "public function response",function response$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    joo.JavaScriptObject.call(this,config);
  },


  /**
   <a href="output/Ext.data.Api.html#Ext.data.Api-actions">Ext.data.Api.actions</a>
   */
  "public native function get action"/*():String*/,

  /**
   * @private
   */
  "public native function set action"/*(value:String):void*/,

  /**

   */
  "public native function get data"/*():**/,

  /**
   * @private
   */
  "public native function set data"/*(value:*):void*/,

  /**

   */
  "public native function get message"/*():String*/,

  /**
   * @private
   */
  "public native function set message"/*(value:String):void*/,

  /**
   The raw response returned from server-code
   */
  "public native function get raw"/*():Object*/,

  /**
   * @private
   */
  "public native function set raw"/*(value:Object):void*/,

  /**
   related to the Request action
   */
  "public native function get records"/*():**/,

  /**
   * @private
   */
  "public native function set records"/*(value:*):void*/,

  /**

   */
  "public native function get success"/*():Boolean*/,

  /**
   * @private
   */
  "public native function set success"/*(value:Boolean):void*/,


];},[],["joo.JavaScriptObject"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/response.js <==
joo.classLoader.prepare("package ext.config",/* {

import joo.JavaScriptObject;*/

/**
 * A generic response class to normalize response-handling internally to the framework.
 *
 * <p>This class serves as a
 * typed config object for constructor of class Response.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.data.Response
 */
{ExtConfig:{target:"ext.data.Response"}},
"public class response extends joo.JavaScriptObject",2,function($$private){var $1=joo;return[ 

  "public function response",function response(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.JavaScriptObject.call(this,config);
  },


  /**
   <a href="output/Ext.data.Api.html#Ext.data.Api-actions">Ext.data.Api.actions</a>
   */
  "public native function get action"/*():String*/,

  /**
   * @private
   */
  "public native function set action"/*(value:String):void*/,

  /**

   */
  "public native function get data"/*():**/,

  /**
   * @private
   */
  "public native function set data"/*(value:*):void*/,

  /**

   */
  "public native function get message"/*():String*/,

  /**
   * @private
   */
  "public native function set message"/*(value:String):void*/,

  /**
   The raw response returned from server-code
   */
  "public native function get raw"/*():Object*/,

  /**
   * @private
   */
  "public native function set raw"/*(value:Object):void*/,

  /**
   related to the Request action
   */
  "public native function get records"/*():**/,

  /**
   * @private
   */
  "public native function set records"/*(value:*):void*/,

  /**

   */
  "public native function get success"/*():Boolean*/,

  /**
   * @private
   */
  "public native function set success"/*(value:Boolean):void*/,


undefined];},[],["joo.JavaScriptObject"], "0.8.0", "0.9.12"
);
